Crate dlccryptlib_py

Crate dlccryptlib_py 

Functions

combine_pubkeys
Combine a number of public keys into one
combine_seckeys
Combine a number of secret keys into one. Warning: Handle secret keys with caution!
create_cet_adaptor_sigs
Create adaptor signatures for a number of CETs
create_deterministic_nonce
Create a nonce value deterministically
create_final_cet_sig
Perform final signing of a CET, decrypt a signature when outcome signatures are available. Return the decrypted signature.
create_final_cet_sigs
Perform final signing of a CET
get_address
Return a child address (specified by index).
get_public_key
Return a child public key (specified by its index).
get_xpub
Return the XPUB
init
Initialize the library, load secret from encrypted file. Return the XPUB.
init_with_entropy
network: “bitcoin”, or “signet”.
reinit_for_testing
sign_hash_ecdsa
Sign a hash with a child private key (specified by index).
sign_schnorr_with_nonce
Sign a message using Schnorr, with a nonce, using a child key
verify_cet_adaptor_sigs
Verify adaptor signatures for a number of CETs
verify_public_key
Verify a child public key.
verify_schnorr
Verify a Schnorr signature over a message, using a child key