Functions
- combine_
pubkeys - Combine a number of public keys into one
- combine_
seckeys - Combine a number of secret keys into one. Warning: Handle secret keys with caution!
- create_
cet_ adaptor_ sigs - Create adaptor signatures for a number of CETs
- create_
deterministic_ nonce - Create a nonce value deterministically
- create_
final_ cet_ sig - Perform final signing of a CET, decrypt a signature when outcome signatures are available. Return the decrypted signature.
- create_
final_ cet_ sigs - Perform final signing of a CET
- get_
address - Return a child address (specified by index).
- get_
public_ key - Return a child public key (specified by its index).
- get_
xpub - Return the XPUB
- init
- Initialize the library, load secret from encrypted file. Return the XPUB.
- init_
with_ entropy - network: “bitcoin”, or “signet”.
- reinit_
for_ testing - sign_
hash_ ecdsa - Sign a hash with a child private key (specified by index).
- sign_
schnorr_ with_ nonce - Sign a message using Schnorr, with a nonce, using a child key
- verify_
cet_ adaptor_ sigs - Verify adaptor signatures for a number of CETs
- verify_
public_ key - Verify a child public key.
- verify_
schnorr - Verify a Schnorr signature over a message, using a child key